package com.guo.gateway.cache;

import com.guo.common.constant.CacheConstants;
import com.guo.gateway.cache.abs.CacheAbs;
import com.guo.gateway.model.NodeJoin;
import com.guo.gateway.model.WorkGatewayNode;
import org.springframework.data.redis.core.ZSetOperations;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @author gxb
 * @description 网关节点连接数
 * @date 2024-04-18 14:27
 */
@Component
public class NodeScoreCache extends CacheAbs<String> {

    @Override
    public String getPre() {
        return CacheConstants.GATEWAY_COMMON;
    }

    public  List<WorkGatewayNode> getNodeScore(){
        Set<ZSetOperations.TypedTuple<String>> range = redisService.redisTemplate.opsForZSet().rangeWithScores(encode(CacheConstants.GATEWAY_NODE_SCORE_CACHE), 0, -1);
        return range.stream()
                .map(ZSet -> WorkGatewayNode.builder().nodeId(ZSet.getValue()).weight(Integer.valueOf(String.valueOf(ZSet.getScore()))).build())
                .toList();

    }



    /**
     * 存入节点ID及连接数
     * @param nodeJoin
     */
    public void save(NodeJoin nodeJoin){
        redisService.setCacheSets(encode(CacheConstants.GATEWAY_NODE_SCORE_CACHE),nodeJoin);
    }

    /**
     * 获取连接数信息
     * @return
     */
    public List<String> get(){
        return redisService.getCacheObject(encode(CacheConstants.GATEWAY_NODE_SCORE_CACHE));
    }



}
